==> mesa_25.0.7.orig.tar.xz: mesa-25.0.7/src/gallium/winsys/lima/drm/lima_drm_public.h <==
/*
 * Copyright © 2017 Lima Project
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice (including the next
 * paragraph) shall be included in all copies or substantial portions of the
 * Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */

#ifndef __LIMA_DRM_PUBLIC_H__
#define __LIMA_DRM_PUBLIC_H__

#include <stdbool.h>

struct pipe_screen;
struct renderonly;

struct pipe_screen *lima_drm_screen_create(int drmFD);
struct pipe_screen *lima_drm_screen_create_renderonly(int fd,
                                                      struct renderonly *ro,
                                                      const struct pipe_screen_config *config);

#endif /* __LIMA_DRM_PUBLIC_H__ */

==> mesa_25.2.4.orig.tar.xz: mesa-25.2.4/src/gallium/winsys/lima/drm/lima_drm_public.h <==
/*
 * Copyright © 2017 Lima Project
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice (including the next
 * paragraph) shall be included in all copies or substantial portions of the
 * Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */

#ifndef __LIMA_DRM_PUBLIC_H__
#define __LIMA_DRM_PUBLIC_H__

#include <stdbool.h>

struct pipe_screen;
struct renderonly;

struct pipe_screen *lima_drm_screen_create(int drmFD,
                                           const struct pipe_screen_config *config);
struct pipe_screen *lima_drm_screen_create_renderonly(int fd,
                                                      struct renderonly *ro,
                                                      const struct pipe_screen_config *config);

#endif /* __LIMA_DRM_PUBLIC_H__ */
